unit ODBF_FD;

interface

uses WinTypes, WinProcs, Classes, Graphics, Forms, Controls, Buttons,
  StdCtrls, ExtCtrls, ODBFTool, ODBF_FDE;

type
  TFieldDefsDlg = class(TForm)
    OKBtn: TBitBtn;
    CancelBtn: TBitBtn;
    HelpBtn: TBitBtn;
    Bevel1: TBevel;
    ListBox: TListBox;
    AddBtn: TBitBtn;
    EditBtn: TBitBtn;
    DeleteBtn: TBitBtn;
    InsertBtn: TBitBtn;
    UpBtn: TBitBtn;
    DownBtn: TBitBtn;
    procedure OKBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure AddBtnClick(Sender: TObject);
    procedure InsertBtnClick(Sender: TObject);
    procedure EditBtnClick(Sender: TObject);
    procedure DeleteBtnClick(Sender: TObject);
    procedure UpBtnClick(Sender: TObject);
    procedure DownBtnClick(Sender: TObject);
    procedure HelpBtnClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    NewFieldDefs: TList;   {Of TDBFFieldDef}
    Procedure InitList (Component: TComponent);
  end;

var
  FieldDefsDlg: TFieldDefsDlg;

implementation

uses ODBF;

var DBFStructure: TDBFStructure;

{$R *.DFM}

Procedure TFieldDefsDlg.InitList (Component: TComponent);
var Index: Integer;
    DBFFieldDef: TDBFFieldDef;
    FieldDefs: TList;
begin
  NewFieldDefs.Clear;
  ListBox.Clear;
  FieldDefs:=(Component as TDBFStructure).FieldList;
  for Index:=0 to FieldDefs.Count-1 do
    begin
      DBFFieldDef:=FieldDefs.Items[Index];
      NewFieldDefs.Add(DBFFieldDef.Copy);
      ListBox.Items.Add(DBFFieldDef.Description);
    end;
  DBFStructure:=Component as TDBFStructure;
  ActiveControl:=ListBox;
end;

procedure TFieldDefsDlg.FormCreate(Sender: TObject);
begin
  NewFieldDefs:=TList.Create;
end;

procedure TFieldDefsDlg.FormDestroy(Sender: TObject);
var Index: Integer;
begin
  for Index:=0 to NewFieldDefs.Count-1 do
    TDBFFieldDef(NewFieldDefs.Items[Index]).Free;
  NewFieldDefs.Clear;
  NewFieldDefs.Free;
end;

procedure TFieldDefsDlg.OKBtnClick(Sender: TObject);
var Index: Integer;
    FieldDefs: TList;
    DBFFieldDef: TDBFFieldDef;
begin
  FieldDefs:=DBFStructure.FieldList;
  for Index:=0 to FieldDefs.Count-1 do
    begin
      DBFFieldDef:=FieldDefs.Items[Index];
      DBFFieldDef.Free;
    end;
  FieldDefs.Clear;
  for Index:=0 to NewFieldDefs.Count-1 do
    begin
      DBFFieldDef:=NewFieldDefs.Items[Index];
      FieldDefs.Add(DBFFieldDef.Copy);
    end;
end;

procedure TFieldDefsDlg.AddBtnClick(Sender: TObject);
var FieldDefEditDlg: TFieldDefEditDlg;
    NewDef: TDBFFieldDef;
begin
  FieldDefEditDlg:=TFieldDefEditDlg.Create(Application);
  try
     FieldDefEditDlg.HelpContext:=HelpContext;
     if FieldDefEditDlg.ShowModal=mrOK then
        begin
          NewDef:=FieldDefEditDlg.DBFFieldDef;
          NewFieldDefs.Add(NewDef.Copy);
          ListBox.ItemIndex:=ListBox.Items.Add(NewDef.Description);
        end;
  finally
     FieldDefEditDlg.Free;
  end;
end;

procedure TFieldDefsDlg.InsertBtnClick(Sender: TObject);
var Index: Integer;
    FieldDefEditDlg: TFieldDefEditDlg;
    NewDef: TDBFFieldDef;
begin
  FieldDefEditDlg:=TFieldDefEditDlg.Create(Application);
  try
     FieldDefEditDlg.HelpContext:=HelpContext;
     if FieldDefEditDlg.ShowModal=mrOK then
        begin
          NewDef:=FieldDefEditDlg.DBFFieldDef;
          Index:=ListBox.ItemIndex;
          if Index>=0 then
             begin
               NewFieldDefs.Insert(Index,NewDef.Copy);
               ListBox.Items.Insert(Index,NewDef.Description);
               ListBox.ItemIndex:=Index;
             end
          else
             begin
               NewFieldDefs.Add(NewDef.Copy);
               ListBox.ItemIndex:=ListBox.Items.Add(NewDef.Description);
             end;
        end;
  finally
     FieldDefEditDlg.Free;
  end;
end;

procedure TFieldDefsDlg.EditBtnClick(Sender: TObject);
var FieldDefEditDlg: TFieldDefEditDlg;
    Index: Integer;
    CurDef, NewDef: TDBFFieldDef;
begin
  Index:=ListBox.ItemIndex;
  if (Index>=0) AND (Index<ListBox.Items.Count) then
     begin
       CurDef:=NewFieldDefs.Items[Index];
       FieldDefEditDlg:=TFieldDefEditDlg.Create(Application);
       FieldDefEditDlg.HelpContext:=HelpContext;
       FieldDefEditDlg.ImportDBFFieldDef(CurDef);
       try
          if FieldDefEditDlg.ShowModal=mrOK then
             begin
               NewDef:=FieldDefEditDlg.DBFFieldDef;
               CurDef.FieldName:=NewDef.FieldName;
               CurDef.FieldType:=NewDef.FieldType;
               CurDef.FieldLength:=NewDef.FieldLength;
               CurDef.FieldDecimals:=NewDef.FieldDecimals;
               ListBox.Items[Index]:=NewDef.Description;
               ListBox.ItemIndex:=Index;
             end;
       finally
          FieldDefEditDlg.Free;
       end;
     end;
end;

procedure TFieldDefsDlg.DeleteBtnClick(Sender: TObject);
var CurDef: TDBFFieldDef;
    Index: Integer;
begin
  Index:=ListBox.ItemIndex;
  if (Index>=0) AND (Index<ListBox.Items.Count) then
     begin
       CurDef:=NewFieldDefs.Items[Index];
       CurDef.Free;
       NewFieldDefs.Delete(Index);
       NewFieldDefs.Pack;
       ListBox.Items.Delete(Index);
     end;
end;

procedure TFieldDefsDlg.UpBtnClick(Sender: TObject);
var Index: Integer;
begin
  Index:=ListBox.ItemIndex;
  if Index>0 then
     begin
       NewFieldDefs.Exchange(Index-1,Index);
       ListBox.Items.Exchange(Index-1,Index);
       ListBox.ItemIndex:=Index-1;
     end;
end;

procedure TFieldDefsDlg.DownBtnClick(Sender: TObject);
var Index: Integer;
begin
  Index:=ListBox.ItemIndex;
  if Index>=0 then
  if Index<ListBox.Items.Count-1 then
     begin
       NewFieldDefs.Exchange(Index,Index+1);
       ListBox.Items.Exchange(Index,Index+1);
       ListBox.ItemIndex:=Index+1;
     end;
end;

procedure TFieldDefsDlg.HelpBtnClick(Sender: TObject);
begin
  Application.HelpContext(HelpContext);
end;

end.

